@@ -98,6 +98,15 @@ has 'state_dir' =>
     lazy_build => 1,
     ) ;
 
+# ---------------------------------------------------------------------------
+
+sub logger
+    {
+    my $self = shift ;
+    
+    Perl::LanguageServer::logger (undef, @_) ;    
+    }
+
 # ----------------------------------------------------------------------------
 
 
